---
name: Feature Request
about: Suggest an idea for this project

---

**Is your feature request related to a problem? Please describe.**

A clear and concise description of what the problem is. E.g. It's annoying that I always have to [...]

**Describe the solution you'd like**

A clear and concise description of the solution you would like to see.

**Describe alternatives you've considered**

A clear and concise description of any alternative solutions or features you've considered.

**Additional context**

Add any other context or screenshots about the feature request here.
